#!/home/steffen/bin/perl
# $Id: daily-dilbert.pl,v 1.2 2010/10/07 19:30:37 steffen Exp steffen $
use strict;
use WWW::Mechanize::GZip;
use Cwd qw( realpath );
use Getopt::Long qw(:config posix_default bundling);

my $base = "$ENV{HOME}/Digikam/Dilbert";
$base = '.' if ! -d $base;
my $start = 0;
my $end   = 400;

sub usage {
	print STDERR <<USAGE;
Get current and older dilbert comics from dilbert1.com and puts them into 
basedir named by date. Prints file names to stdout.
Usage: $0 [options]
Options: 
 -h|--help          this screen
 -B|--basedir dir   dir where to put the images ($base)
 -S|--start S       how many dates back from now to start ($start)
 -E|--end E         how many dates back from now end ($end)
USAGE
	exit(2)
}

GetOptions(
	'B|base=s'  => \$base,
	'S|start=i' => \$start,
	'E|end=i'   => \$end,
	'h|help'    => \&usage,
) or usage();
-d $base or die "no basedir $base";


my $bot = WWW::Mechanize::GZip->new;
for( my $i = $start; $i<$end;$i++ ) {
	my $time = time() -24*3600*$i;
	my @t = localtime($time);
	my $fbase = sprintf "$base/dilbert%04d%02d%02d", 1900+$t[5],$t[4]+1,$t[3];
	last if -f "$fbase.gif" or -f "$fbase.jpg";
	my $url = sprintf "http://www.dilbert.com/strips/comic/%04d-%02d-%02d/",
		1900+$t[5],$t[4]+1,$t[3];
	warn "try $url\n";
	if ( my $resp = $bot->get( $url )) {
		if ( $bot->uri =~m{/strips/?$} ) {
			# redirect zur Startseite -offensichtlich fr den Tag noch kein strip
			warn "no strip for $fbase: $url got redirected to ".$bot->uri."\n";
			next;
		}
		if ( my $link = $bot->find_image( url_regex => qr/\.strip\.(?:\w+\.)?(gif|jpg)$/ )) {
			$link->url =~m{\.(gif|jpg)$};
			my $fname = "$fbase.$1";
			$bot->get( $link->url ) or die "cannot get ".$link->url;
			open( my $fh,'>',$fname ) || die $!;
			print $fh $bot->content;
			print "$fname\n";
		} else {
			die "no link matching regex in $url\n".$resp->as_string;
		}
	} else {
		warn "no strip for $fbase at $url\n";
	}
}

